summaryrefslogtreecommitdiffstats
path: root/src/import
diff options
context:
space:
mode:
authorClaus Michael Olsen <cmolsen@us.ibm.com>2017-12-12 11:20:34 -0600
committerSachin Gupta <sgupta2m@in.ibm.com>2018-01-03 08:27:46 -0500
commitefddbeeb75d9b9d67849c493fb6f90211e9f318d (patch)
treee01722b0e8b64dc8a27db87ab10fa923ca552d02 /src/import
parent560106553412bfbb0351c1a7644a95b7c04c332d (diff)
downloadtalos-sbe-efddbeeb75d9b9d67849c493fb6f90211e9f318d.tar.gz
talos-sbe-efddbeeb75d9b9d67849c493fb6f90211e9f318d.zip
Adding CT_P9A to the enum list of chip types.
I inserted P9A before CT_CEN for purely estaetic reasons. Since the current Centaur image in EKB isn't being used yet, this should be safe (as otherwise there would be a co-req situation). Change-Id: Ia5ef9950644eacea3fdc28a0195502bdcae44327 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/50812 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: HWSV CI <hwsv-ci+hostboot@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Joseph J. McGill <jmcgill@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Reviewed-by: Richard J. Knight <rjknight@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/50962 Reviewed-by: Sachin Gupta <sgupta2m@in.ibm.com>
Diffstat (limited to 'src/import')
-rw-r--r--src/import/chips/common/utils/imageProcs/common_ringId.H11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/import/chips/common/utils/imageProcs/common_ringId.H b/src/import/chips/common/utils/imageProcs/common_ringId.H
index f61cc397..2f55d2d6 100644
--- a/src/import/chips/common/utils/imageProcs/common_ringId.H
+++ b/src/import/chips/common/utils/imageProcs/common_ringId.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER sbe Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2017 */
+/* Contributors Listed Below - COPYRIGHT 2017,2018 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -134,13 +134,13 @@ enum TorMagicNum
//
// Chip types and List to represent p9n, p9c, cen (centaur)
// NB! There's a matching CHIP_TYPE_LIST definition in common_ringId.C
//
enum ChipType
{
- CT_P9N, // ==P9 for now
- CT_P9C, // ==P9 for now
+ CT_P9N,
+ CT_P9C,
+ CT_P9A,
CT_CEN,
NUM_CHIP_TYPES
};
@@ -155,6 +155,7 @@ static const ChipTypeList_t CHIP_TYPE_LIST[] =
{
{"p9n", CT_P9N},
{"p9c", CT_P9C},
+ {"p9a", CT_P9A},
{"cen", CT_CEN},
};
OpenPOWER on IntegriCloud
@@ -134,13 +134,13 @@ enum TorMagicNum
//
-// Chip types and List to represent p9n, p9c, cen (centaur)
-// NB! There's a matching CHIP_TYPE_LIST definition in common_ringId.C
+// Chip types and List to represent p9n, p9c, p9a, cen (centaur)
//
enum ChipType